/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.remote.app.web.internal.frontend.taglib.clay.data.set.view.table;

import com.liferay.frontend.taglib.clay.data.set.ClayDataSetDisplayView;
import com.liferay.frontend.taglib.clay.data.set.view.table.BaseTableClayDataSetDisplayView;
import com.liferay.frontend.taglib.clay.data.set.view.table.ClayTableSchema;
import com.liferay.frontend.taglib.clay.data.set.view.table.ClayTableSchemaBuilder;
import com.liferay.frontend.taglib.clay.data.set.view.table.ClayTableSchemaBuilderFactory;
import com.liferay.frontend.taglib.clay.data.set.view.table.ClayTableSchemaField;
import com.liferay.remote.app.web.internal.constants.RemoteAppAdminConstants;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Bruno Basto
 */
@Component(
	immediate = true,
	property = "clay.data.set.display.name=" + RemoteAppAdminConstants.REMOTE_APP_ENTRY_DATA_SET_DISPLAY,
	service = ClayDataSetDisplayView.class
)
public class RemoteAppEntryTableClayDataSetDisplayView
	extends BaseTableClayDataSetDisplayView {

	@Override
	public ClayTableSchema getClayTableSchema() {
		ClayTableSchemaBuilder clayTableSchemaBuilder =
			_clayTableSchemaBuilderFactory.create();

		_addClayTableSchemaField(
			clayTableSchemaBuilder, "name", "name", "actionLink");
		_addClayTableSchemaField(clayTableSchemaBuilder, "type", "type");

		return clayTableSchemaBuilder.build();
	}

	private void _addClayTableSchemaField(
		ClayTableSchemaBuilder clayTableSchemaBuilder, String fieldName,
		String label) {

		_addClayTableSchemaField(
			clayTableSchemaBuilder, fieldName, label, null);
	}

	private void _addClayTableSchemaField(
		ClayTableSchemaBuilder clayTableSchemaBuilder, String fieldName,
		String label, String contentRenderer) {

		ClayTableSchemaField clayTableSchemaField =
			clayTableSchemaBuilder.addClayTableSchemaField(fieldName, label);

		if (contentRenderer != null) {
			clayTableSchemaField.setContentRenderer(contentRenderer);
		}
	}

	@Reference
	private ClayTableSchemaBuilderFactory _clayTableSchemaBuilderFactory;

}