/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.remote.app.web.internal.upgrade;

import com.liferay.portal.kernel.dao.orm.QueryUtil;
import com.liferay.portal.kernel.upgrade.BasePortletIdUpgradeProcess;
import com.liferay.portal.kernel.upgrade.UpgradeStep;
import com.liferay.portal.upgrade.registry.UpgradeStepRegistrator;
import com.liferay.portal.vulcan.util.TransformUtil;
import com.liferay.remote.app.service.RemoteAppEntryLocalService;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Iván Zaera Avellón
 */
@Component(immediate = true, service = UpgradeStepRegistrator.class)
public class RemoteAppAdminWebUpgrade implements UpgradeStepRegistrator {

	@Override
	public void register(Registry registry) {
		UpgradeStep upgradePortletId = new BasePortletIdUpgradeProcess() {

			@Override
			protected String[][] getRenamePortletIdsArray() {
				return TransformUtil.transformToArray(
					_remoteAppEntryLocalService.getRemoteAppEntries(
						QueryUtil.ALL_POS, QueryUtil.ALL_POS),
					remoteAppEntry -> new String[] {
						"remote_app_" + remoteAppEntry.getRemoteAppEntryId(),
						"com_liferay_remote_app_web_internal_portlet_" +
							"RemoteAppEntryPortlet_" +
								remoteAppEntry.getRemoteAppEntryId()
					},
					String[].class);
			}

		};

		registry.register("0.0.0", "1.0.0", upgradePortletId);
	}

	@Reference
	private RemoteAppEntryLocalService _remoteAppEntryLocalService;

}